XActor Internals
================

MPI Async Communication Manager
-------------------------------

.. autoclass:: xactor.mpi_acomm.AsyncCommunicator
  :members:

.. autoclass:: xactor.mpi_acomm.AsyncReceiver
  :members:

.. autoclass:: xactor.mpi_acomm.AsyncBufferedSender
  :members:

.. autoclass:: xactor.mpi_acomm.AsyncRawSender
  :members:

MPI Rank Actor
--------------

.. autoclass:: xactor.mpi_rank_actor.MPIRankActor
  :members:
